==> beacon_0_1_0.zip: beacon/beacon/language/en_admin.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of beacon
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


// EDIT PAGE
$lang['hdr_files'] = 						"files";
$lang['hdr_menu_items'] = 					"menu items";
$lang['hdr_items'] = 						"Beacon items";
$lang['hdr_categories'] = 					"Beacon categories";
$lang['hdr_edit_item'] = 					"edit an article";
$lang['hdr_article_details'] = 				"article details";
$lang['hdr_article_publishing'] = 			"article publishing";
$lang['hdr_upload_file'] = 					"upload file";
$lang['hdr_menu_list'] = 					"menu listing";
$lang['hdr_menu_edit'] = 					"update menu item";
$lang['hdr_register_login'] = 				"login or register";
$lang['hdr_contributors'] = 				"contributors";

$lang['form_label_title'] = 				"title";
$lang['form_body'] = 						"article";

$lang['form_submit_save_go'] = 				"SAVE AND GO";
$lang['form_submit_save'] = 				"SAVE";
$lang['form_submit_update'] = 				"update";
$lang['form_submit_insert'] = 				"insert";
$lang['form_submit_delete'] = 				"DELETE";

$lang['form_label_preview'] = 				"preview";
$lang['form_label_synopsis'] = 				"synopsis";
$lang['form_label_wiki_page'] = 			"wiki page";
$lang['form_label_language'] = 				"language";
$lang['form_label_category'] = 				"category";
$lang['form_label_beacon_default_page'] = 	"default";
$lang['form_label_category_name'] = 		"category name";
$lang['form_label_ext_link'] = 				"external link";
$lang['form_label_wikipage'] = 				"wikipage";
$lang['form_label_allow_comment'] = 		"allow comments";

$lang['txt_none'] = 						"none";
$lang['txt_add_file'] = 					"add your file";
$lang['txt_title'] = 						"title";
$lang['txt_items_intro'] = 					"These items are listed in page name, date order. Click on one to edit it.";
$lang['txt_categories_intro'] = 			"Beacon has categories which can be used to group together different categories of articles.";
$lang['txt_categories'] = 					"categories";
$lang['txt_edit_category'] = 				"edit category";
$lang['txt_edit_category_intro'] = 			"You can start with adding a 'top level category'. To place sub categories press the '+' to the left of the category. To edit the category press the category name.";
$lang['txt_edit_category_option1'] = 		"You are placing a category under";
$lang['txt_edit_category_option2'] = 		"You are editing";
$lang['txt_edit_category_option3'] = 		"You are creating a top level category.";
$lang['txt_edit_item_intro'] = 				"Fill in the details below. You can save at any time or preview. Save and go when you are done.";
$lang['txt_article_detail_intro'] = 		"The synopsis is a small text describing the article. It is used in lists such as search results.";
$lang['txt_article_publishing_intro'] = 	"The default article is the article which is displayed by default on the home page (when you first come to the site). Check the box to make this the default article.";
$lang['txt_wiki_intro'] = 					"The Wiki page is the page name that you can link to from within any article in beacon. It must be formatted in Studly caps which LooksLikeThis.";
$lang['txt_upload_file_intro'] = 			"You can upload gif, png, jpg, pdf or txt files.";
$lang['txt_menu_items_intro'] = 			"You can alter and add menu items to the menus listed. See the administrators guide if you require a new menu.";
$lang['txt_menu_edit_intro'] = 				"Select menu location and type your menu title.";
$lang['txt_menu_location'] = 				"Menu location";
$lang['txt_menu_type_intro'] = 				"You can either link the menu item to a category, a wikipage or an external link.";
$lang['txt_menu_order'] = 					"order";
$lang['txt_register_login_intro'] = 		"Beacon requires you to login in to leave comments or make changes to the site. If you have an account with us please login in. If you do not please register.(free). Please read the <a href='index.php?page=SitePolicy'>site policy</a> guide before registering.";
$lang['txt_contributors'] = 				"contributor listing";
$lang['txt_edit_contributor'] = 			"update a contributors privileges";
$lang['txt_edit_contributor_intro'] = 		"You can give a contributor access to the admin functionality of this site by checking the desired boxes below.";
$lang['txt_contributors_intro'] = 			"List and change permissions for your contributors.";
$lang['txt_filenames'] = 					"files";
$lang['txt_wikipagenames'] = 				"wiki links";

$lang['href_add_file'] = 					"add file";
$lang['href_list'] = 						"list";
$lang['href_information'] = 				"help";
$lang['href_new_category'] = 				"add new top level category";
$lang['href_add_item'] = 					"add item";
$lang['href_add_menu'] = 					"add menu item";

$lang['sub_update'] = 						"update";
$lang['sub_delete'] = 						"delete";
$lang['sub_upload'] = 						"upload";

// REGISTER PAGE
$lang['txt_name'] = 						"name or nic";
$lang['txt_email'] = 						"email";
$lang['txt_password'] = 					"password";
$lang['txt_login'] = 						"login";
$lang['txt_login_intro'] = 					"You need to login in to post to this site. If you have forgotten your password please email beacon-at-barnraiser-dot-org from the email account you provided.";
$lang['txt_register'] = 					"register";
$lang['txt_register_intro'] = 				"You are welcome to register with us. We will not use your information for anything other than to contact you to clarify your posts if we are unsure of your post.";
$lang['txt_show_email'] = 					"Are you ok for us to show that so that other people can contact you?";
$lang['txt_allow_correspondence'] = 		"We may wish to contact you with an occasional newsletter. Is it ok for us to send that to you?";
$lang['txt_email_intro'] = 					"Please note, your email address is displayed in the format name-at-domain-dot-org to stop robots picking it up. It is only shown if you check the box below.";
$lang['txt_password_intro'] = 				"Use more than 5 characters. Your password is encoded when stored in our database so we can't see it.";
$lang['txt_edit_contributor_intro1'] = 		"Select the contributor number to the left to update the contributors permissions.";

$lang['txt_captcha'] = 						"captcha";
$lang['txt_captcha_intro'] = 				"Please type the word you see. The word is case sensitive so, enter the word exactly as you see it.";

//ARRAYS
$lang['arr_menu'][1] = 						"side menu";
$lang['arr_menu'][2] = 						"base menu";

$lang['arr_menu_type'][1] = 				"wikipage";
$lang['arr_menu_type'][1] = 				"category";
$lang['arr_menu_type'][2] = 				"external link";

$lang['arr_permissions'][1] = 				"edit contributors";
$lang['arr_permissions'][2] = 				"edit file";
$lang['arr_permissions'][3] = 				"edit item";
$lang['arr_permissions'][4] = 				"edit menu";
$lang['arr_permissions'][5] = 				"edit category";

?>

==> beacon_0_1_3.zip: beacon/beacon/language/en_admin.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of beacon
// 
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------


// EDIT PAGE
$lang['hdr_files'] = 						"files";
$lang['hdr_menu_items'] = 					"menu items";
$lang['hdr_items'] = 						"Beacon items";
$lang['hdr_categories'] = 					"Beacon categories";
$lang['hdr_edit_item'] = 					"edit an article";
$lang['hdr_article_details'] = 				"article details";
$lang['hdr_article_publishing'] = 			"article publishing";
$lang['hdr_upload_file'] = 					"upload file";
$lang['hdr_menu_list'] = 					"menu listing";
$lang['hdr_menu_edit'] = 					"update menu item";
$lang['hdr_register_login'] = 				"login or register";
$lang['hdr_contributors'] = 				"contributors";

$lang['form_label_title'] = 				"title";
$lang['form_body'] = 						"article";

$lang['form_submit_save_go'] = 				"SAVE AND GO";
$lang['form_submit_save'] = 				"SAVE";
$lang['form_submit_update'] = 				"update";
$lang['form_submit_insert'] = 				"insert";
$lang['form_submit_delete'] = 				"DELETE";

$lang['form_label_preview'] = 				"preview";
$lang['form_label_synopsis'] = 				"synopsis";
$lang['form_label_wiki_page'] = 			"wiki page";
$lang['form_label_language'] = 				"language";
$lang['form_label_category'] = 				"category";
$lang['form_label_beacon_default_page'] = 	"default";
$lang['form_label_category_name'] = 		"category name";
$lang['form_label_ext_link'] = 				"external link";
$lang['form_label_wikipage'] = 				"wikipage";
$lang['form_label_allow_comment'] = 		"allow comments";

$lang['txt_none'] = 						"none";
$lang['txt_add_file'] = 					"add your file";
$lang['txt_title'] = 						"title";
$lang['txt_items_intro'] = 					"These items are listed in page name, date order. Click on one to edit it.";
$lang['txt_categories_intro'] = 			"Beacon has categories which can be used to group together different categories of articles.";
$lang['txt_categories'] = 					"categories";
$lang['txt_edit_category'] = 				"edit category";
$lang['txt_edit_category_intro'] = 			"You can start with adding a 'top level category'. To place sub categories press the '+' to the left of the category. To edit the category press the category name.";
$lang['txt_edit_category_option1'] = 		"You are placing a category under";
$lang['txt_edit_category_option2'] = 		"You are editing";
$lang['txt_edit_category_option3'] = 		"You are creating a top level category.";
$lang['txt_edit_item_intro'] = 				"Fill in the details below. You can save at any time or preview. Save and go when you are done.";
$lang['txt_article_detail_intro'] = 		"The synopsis is a small text describing the article. It is used in lists such as search results.";
$lang['txt_article_publishing_intro'] = 	"The default article is the article which is displayed by default on the home page (when you first come to the site). Check the box to make this the default article.";
$lang['txt_wiki_intro'] = 					"The Wiki page is the page name that you can link to from within any article in beacon. It must be formatted in Studly caps which LooksLikeThis.";
$lang['txt_upload_file_intro'] = 			"You can upload gif, png, jpg, pdf or txt files.";
$lang['txt_menu_items_intro'] = 			"You can alter and add menu items to the menus listed. See the administrators guide if you require a new menu.";
$lang['txt_menu_edit_intro'] = 				"Select menu location and type your menu title.";
$lang['txt_menu_location'] = 				"Menu location";
$lang['txt_menu_type_intro'] = 				"You can either link the menu item to a category, a wikipage or an external link.";
$lang['txt_menu_order'] = 					"order";
$lang['txt_register_login_intro'] = 		"Beacon requires you to login in to leave comments or make changes to the site. If you have an account with us please login in. If you do not please register.(free). Please read the <a href='index.php?page=SitePolicy'>site policy</a> guide before registering.";
$lang['txt_contributors'] = 				"contributor listing";
$lang['txt_edit_contributor'] = 			"update a contributors privileges";
$lang['txt_edit_contributor_intro'] = 		"You can give a contributor access to the admin functionality of this site by checking the desired boxes below.";
$lang['txt_contributors_intro'] = 			"List and change permissions for your contributors.";
$lang['txt_filenames'] = 					"files";
$lang['txt_wikipagenames'] = 				"wiki links";
$lang['txt_menu_list_intro'] = 				"You can edit a menu item by clicking on it or add a new menu item by clicking the 'add menu item' button.";

$lang['href_add_file'] = 					"add file";
$lang['href_list'] = 						"list";
$lang['href_information'] = 				"help";
$lang['href_new_category'] = 				"add new top level category";
$lang['href_add_item'] = 					"add item";
$lang['href_add_menu'] = 					"add menu item";

$lang['sub_update'] = 						"update";
$lang['sub_delete'] = 						"delete";
$lang['sub_upload'] = 						"upload";

// REGISTER PAGE
$lang['txt_name'] = 						"name or nic";
$lang['txt_email'] = 						"email";
$lang['txt_password'] = 					"password";
$lang['txt_login'] = 						"login";
$lang['txt_login_intro'] = 					"You need to login in to post to this site. If you have forgotten your password please email beacon-at-barnraiser-dot-org from the email account you provided.";
$lang['txt_register'] = 					"register";
$lang['txt_register_intro'] = 				"You are welcome to register with us. We will not use your information for anything other than to contact you to clarify your posts if we are unsure of your post.";
$lang['txt_show_email'] = 					"Are you ok for us to show that so that other people can contact you?";
$lang['txt_allow_correspondence'] = 		"We may wish to contact you with an occasional newsletter. Is it ok for us to send that to you?";
$lang['txt_email_intro'] = 					"Please note, your email address is displayed in the format name-at-domain-dot-org to stop robots picking it up. It is only shown if you check the box below.";
$lang['txt_password_intro'] = 				"Use more than 5 characters. Your password is encoded when stored in our database so we can't see it.";
$lang['txt_edit_contributor_intro1'] = 		"Select the contributor number to the left to update the contributors permissions.";

$lang['txt_captcha'] = 						"captcha";
$lang['txt_captcha_intro'] = 				"Please type the word you see. The word is case sensitive so, enter the word exactly as you see it.";

//ARRAYS
$lang['arr_menu'][1] = 						"side menu";
$lang['arr_menu'][2] = 						"base menu";

$lang['arr_menu_type'][1] = 				"wikipage";
$lang['arr_menu_type'][1] = 				"category";
$lang['arr_menu_type'][2] = 				"external link";

$lang['arr_permissions'][1] = 				"edit contributors";
$lang['arr_permissions'][2] = 				"edit file";
$lang['arr_permissions'][3] = 				"edit item";
$lang['arr_permissions'][4] = 				"edit menu";
$lang['arr_permissions'][5] = 				"edit category";

?>
